==> basicMLpy-1.0.6.tar.gz: basicMLpy-1.0.6/README.md <==
# basicMLpy <br />
basicMLpy is a package that implements simple machine learning algorithms. It currently contains seven modules that implement multiple machine learning techniques for supervised learning.<br />
### The basicMLpy.regression module contains the following functionalities:
* Linear Regression 
* Ridge Regression 
### The basicMLpy.classification module contains the following functionalities:
* Multiclass classification through the IRLS(Iteratively Reweighted Least Squares) algorithm
### The basicMLpy.nearest_neighbors module contains the following functionalities:
* An implementation of the K-Nearest Neighbors algorithm, that can fit both classification and regression problems
### The basicMLpy.model_selection module contains the following functionalities:
* A Cross-Validation algorithm for the functions presented by the basicMLpy package
### The basicMLpy.ensemble module contains the following functionalities:
* An implementation of the Random Forests algorithm for regression and classification
* An implementation of the AdaBoost algorithm for classification
* An implementation of the Gradient Boosting algorithm for regression
### The basicMLpy.decomposition module contains the following functionalities:
* An implementation of the SVD decomposition algorithm
* An implementation of the PCA algorithm
### The basicMLpy.loss_functions module contains the following functionalities:
* Multiple functions for error evaluation, e.g. MSE, MAE, exponential loss, etc.
### The basicMLpy.utils module contains the following functionalities:
* Useful functions utilized all throughout the other models.
## Documentation <br />
The documentation will be available at a proper site soon. For now it can be found in the main code for each module.<br />
## Installation <br />
To install basicMLpy run the following command: <br />
`pip install basicMLpy` <br />
## Dependencies <br />
basicMLpy requires Python >= 3.8, Numpy >= 1.19, Scipy >= 1.5.2, scikit-learn >= 0.23. <br />
## On Github <br />
https://github.com/HenrySilvaCS/basicMLpy
## Some thoughts <br />
This is a work in progress project, so more functionalities will be added with time. The main feature that will be implemented in the near future is a decomposition module.
## Author <br />
Henrique Soares Assumpção e Silva

==> basicMLpy-1.0.8.tar.gz: basicMLpy-1.0.8/README.md <==
# basicMLpy <br />
basicMLpy is a package that implements simple machine learning algorithms. It currently contains eight modules that implement multiple machine learning techniques for supervised learning.<br />
### The basicMLpy.regression module contains the following functionalities:
* Linear Regression 
* Ridge Regression 
### The basicMLpy.classification module contains the following functionalities:
* Multiclass classification through the IRLS(Iteratively Reweighted Least Squares) algorithm
### The basicMLpy.nearest_neighbors module contains the following functionalities:
* An implementation of the K-Nearest Neighbors algorithm, that can fit both classification and regression problems
### The basicMLpy.model_selection module contains the following functionalities:
* A Cross-Validation algorithm for the functions presented by the basicMLpy package
### The basicMLpy.ensemble module contains the following functionalities:
* An implementation of the Random Forests algorithm for regression and classification
* An implementation of the AdaBoost algorithm for classification
* An implementation of the Gradient Boosting algorithm for regression
### The basicMLpy.decomposition module contains the following functionalities:
* An implementation of the SVD decomposition algorithm
* An implementation of the PCA algorithm
### The basicMLpy.loss_functions module contains the following functionalities:
* Multiple functions for error evaluation, e.g. MSE, MAE, exponential loss, etc.
### The basicMLpy.utils module contains the following functionalities:
* Useful functions utilized all throughout the other models.
## Installation <br />
To install basicMLpy run the following command: <br />
`pip install basicMLpy` <br />
## Package's site and documentation <br />
https://henrysilvacs.github.io/basicMLpy/
## Dependencies <br />
basicMLpy requires Python >= 3.8, Numpy >= 1.19, Scipy >= 1.5.2, scikit-learn >= 0.23. <br />
## On Github <br />
https://github.com/HenrySilvaCS/basicMLpy
## On Pypi <br />
https://pypi.org/project/basicMLpy/
## Some thoughts <br />
This is a work in progress project, so more functionalities will be added with time.
## Author <br />
Henrique Soares Assumpção e Silva
